@@ -2,6 +2,7 @@ import os
 from typing import Tuple
 
 import click
+import requests
 
 from .env_keys import ORGANIZATION_KEY, TOKEN_KEY, WORKSPACE_KEY
 
@@ -22,10 +23,12 @@ def get_org_workspace():
 def ensure_org_workspace() -> Tuple[str, str]:
     org, workspace = get_org_workspace()
     if org is None or workspace is None:
-        raise click.UsageError(click.style(
-            "Could not identify Launchable organization/workspace. "
-            "Please confirm if you set LAUNCHABLE_TOKEN or LAUNCHABLE_ORGANIZATION and LAUNCHABLE_WORKSPACE environment variables",
-            fg="red"))
+        raise click.UsageError(
+            click.style(
+                "Could not identify Launchable organization/workspace. "
+                "Please confirm if you set LAUNCHABLE_TOKEN or LAUNCHABLE_ORGANIZATION and "
+                "LAUNCHABLE_WORKSPACE environment variables",
+                fg="red"))
     return org, workspace
 
 
@@ -34,6 +37,25 @@ def authentication_headers():
     if token:
         return {'Authorization': 'Bearer {}'.format(token)}
 
+    if os.getenv('EXPERIMENTAL_GITHUB_OIDC_TOKEN_AUTH'):
+        req_url = os.getenv('ACTIONS_ID_TOKEN_REQUEST_URL')
+        rt_token = os.getenv('ACTIONS_ID_TOKEN_REQUEST_TOKEN')
+        if not req_url or not rt_token:
+            raise click.UsageError(
+                click.style(
+                    "GitHub Actions OIDC tokens cannot be retrieved."
+                    "Confirm that you have added necessary permissions following "
+                    "https://docs.github.com/en/actions/deployment/security-hardening-your-deployments/configuring-openid-connect-in-cloud-providers#adding-permissions-settings",  # noqa: E501
+                    fg="red"))
+        r = requests.get(req_url,
+                         headers={
+                             'Authorization': 'Bearer {}'.format(rt_token),
+                             'Accept': 'application/json; api-version=2.0',
+                             'Content-Type': 'application/json',
+                         })
+        r.raise_for_status()
+        return {'Authorization': 'Bearer {}'.format(r.json()['value'])}
+
     if os.getenv('GITHUB_ACTIONS'):
         headers = {
             'GitHub-Actions': os.environ['GITHUB_ACTIONS'],
