@@ -24,6 +24,7 @@ class CliTestCase(unittest.TestCase):
     launchable_token = "v1:{}/{}:auth-token-sample".format(organization, workspace)
     session_id = 16
     build_name = "123"
+    session_name = "test_session_name"
     subsetting_id = 456
     session = "builds/{}/test_sessions/{}".format(build_name, session_id)
 
@@ -109,6 +110,29 @@ class CliTestCase(unittest.TestCase):
                 'isObservation': False,
             },
             status=200)
+        responses.add(
+            responses.GET,
+            "{}/intake/organizations/{}/workspaces/{}/builds/{}/test_session_names/{}".format(
+                get_base_url(),
+                self.organization,
+                self.workspace,
+                self.build_name,
+                self.session_name),
+            json={
+                'id': self.session_id,
+                'isObservation': False,
+            },
+            status=200)
+        responses.add(
+            responses.PATCH,
+            "{}/intake/organizations/{}/workspaces/{}/builds/{}/test_sessions/{}".format(
+                get_base_url(),
+                self.organization,
+                self.workspace,
+                self.build_name,
+                self.session_id),
+            json={'name': self.session_name},
+            status=200)
         responses.add(
             responses.PATCH,
             "{}/intake/organizations/{}/workspaces/{}/builds/{}/test_sessions/{}/close".format(
