@@ -1,3 +1,5 @@
+import gzip
+import json
 import os
 import tempfile
 from unittest import mock
@@ -164,9 +166,98 @@ class SubsetTest(CliTestCase):
         rest.close()
         os.unlink(rest.name)
 
+    @responses.activate
+    @mock.patch.dict(os.environ, {"LAUNCHABLE_TOKEN": CliTestCase.launchable_token})
+    def test_subset_targetless(self):
+        pipe = "test_aaa.py\ntest_bbb.py\ntest_ccc.py\ntest_eee.py\ntest_fff.py\ntest_ggg.py"
+        responses.replace(
+            responses.POST,
+            "{}/intake/organizations/{}/workspaces/{}/subset".format(
+                get_base_url(),
+                self.organization,
+                self.workspace),
+            json={
+                "testPaths": [
+                    [{"type": "file", "name": "test_aaa.py"}],
+                    [{"type": "file", "name": "test_bbb.py"}],
+                    [{"type": "file", "name": "test_ccc.py"}],
+                ],
+                "testRunner": "file",
+                "rest": [
+                    [{"type": "file", "name": "test_eee.py"}],
+                    [{"type": "file", "name": "test_fff.py"}],
+                    [{"type": "file", "name": "test_ggg.py"}],
+                ],
+                "subsettingId": 123,
+                "summary": {
+                    "subset": {"duration": 10, "candidates": 3, "rate": 50},
+                    "rest": {"duration": 10, "candidates": 3, "rate": 50}
+                },
+            },
+            status=200)
+
+        result = self.cli(
+            "subset",
+            "--session",
+            self.session,
+            "file",
+            input=pipe,
+            mix_stderr=False)
+        self.assertEqual(result.exit_code, 0)
+
+        payload = json.loads(gzip.decompress(responses.calls[0].request.body).decode())
+        self.assertTrue(payload.get('useServerSideOptimizationTarget'))
+
+    @responses.activate
+    @mock.patch.dict(os.environ, {"LAUNCHABLE_TOKEN": CliTestCase.launchable_token})
+    def test_subset_ignore_flaky_tests_above(self):
+        pipe = "test_aaa.py\ntest_bbb.py\ntest_ccc.py\ntest_flaky.py"
+        responses.replace(
+            responses.POST,
+            "{}/intake/organizations/{}/workspaces/{}/subset".format(
+                get_base_url(),
+                self.organization,
+                self.workspace),
+            json={
+                "testPaths": [
+                    [{"type": "file", "name": "test_aaa.py"}],
+                    [{"type": "file", "name": "test_bbb.py"}],
+
+                ],
+                "testRunner": "file",
+                "rest": [
+                    [{"type": "file", "name": "test_ccc.py"}],
+                ],
+                "subsettingId": 123,
+                "summary": {
+                    "subset": {"duration": 20, "candidates": 2, "rate": 67},
+                    "rest": {"duration": 10, "candidates": 1, "rate": 33}
+                },
+            },
+            status=200)
+
+        result = self.cli(
+            "subset",
+            "--session",
+            self.session,
+            "--ignore-flaky-tests-above",
+            0.05,
+            "file",
+            input=pipe,
+            mix_stderr=False)
+        self.assertEqual(result.exit_code, 0)
+
+        payload = json.loads(gzip.decompress(responses.calls[0].request.body).decode())
+        self.assertEqual(payload.get('dropFlakinessThreshold'), 0.05)
+
     @ responses.activate
     @ mock.patch.dict(os.environ, {"LAUNCHABLE_TOKEN": CliTestCase.launchable_token})
     def test_subset_with_get_tests_from_previous_full_runs(self):
+        # check error when input candidates are empty without --get-tests-from-previous-sessions option
+        result = self.cli("subset", "--target", "30%", "--session", self.session, "file")
+        self.assertEqual(result.exit_code, 1)
+        self.assertTrue("Please set subset candidates or use `--get-tests-from-previous-sessions` option" in result.stdout)
+
         responses.replace(
             responses.POST,
             "{}/intake/organizations/{}/workspaces/{}/subset".format(
